@@ -1,14 +1,15 @@
-#!/usr/bin/env python
+__all__ = ['cached']
+
+
 import collections
 import inspect
 from decorator import decorator
-from public import public
 
 results = collections.defaultdict(dict)
 
 
-@public
 def cached(function):
+    """`@cache` decorator, `cache(function)` - cache function result"""
     if not inspect.isfunction(function):
         err = "@cached requires function"
         raise TypeError(err)
